import { ArrowLeft, Instagram, Link, Mail, MapPin } from 'lucide-react';
import { useEffect } from 'react';
import { Card } from 'react-bootstrap';
import { useDispatch, useSelector } from 'react-redux';
import { useNavigate, useParams } from 'react-router-dom';
import { selectCreator, clearCreator } from '../store/slices/creatorsSlice';
import { Doughnut } from 'react-chartjs-2';

const data = {
    labels: ['Red', 'Blue', 'Green', 'Purple'],
    datasets: [
        {
            label: 'GMV',
            data: [12, 19, 5, 2],
            backgroundColor: ['rgba(217, 107, 139)', 'rgba(101, 105, 225)', 'rgba(93, 200, 179)', 'rgba(122, 87, 218)'],
        },
    ],
};

const options = {
    cutout: 70,
    plugins: {
        legend: {
            position: 'bottom',
            labels: {
                generateLabels: function (chart) {
                    return chart.data.labels.map((label, index) => {
                        const value = chart.data.datasets[0].data[index];
                        return {
                            text: `${label} ${value}%`,
                            fillStyle: chart.data.datasets[0].backgroundColor[index],
                            strokeStyle: chart.data.datasets[0].backgroundColor[index],
                            index: index,
                        };
                    });
                },
            },
        },
    },
};

export default function CreatorDetail({}) {
    const { id } = useParams();
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const { selectedCreator } = useSelector((state) => state.creators);

    const handleBack = () => {
        navigate(-1);
    };
    useEffect(() => {
        dispatch(selectCreator(id));
        return () => {
            dispatch(clearCreator());
        };
    }, [dispatch, id]);
    console.log(selectedCreator);
    return (
        <div className='creator-detail-page'>
            <div className='back-button' onClick={handleBack}>
                <ArrowLeft size={16} /> Go back
            </div>
            {selectedCreator ? (
                <div className='creator-info-detail-container'>
                    <div className='creator-info-container'>
                        <div className='creator-info-1'>
                            <div className='creator-avatar'>
                                <img src={selectedCreator.avatar} alt={selectedCreator.name} />
                            </div>
                            <div className='creator-info-right'>
                                <div className='creator-name'>{selectedCreator.name}</div>
                                <div className='creator-desc'>{selectedCreator.description || '--'}</div>
                                <div className='creator-category'>{selectedCreator.category || '--'}</div>
                                <div className='creator-location'>
                                    <MapPin size={16} />
                                    {selectedCreator.location || ' --'}
                                </div>
                                <div className='creator-live-time'>{selectedCreator.liveTime || '--'}</div>
                            </div>
                        </div>
                        <div className='creator-info-2'>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>Category</div>
                                <div className='creator-info-value'>{selectedCreator.category}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>MCN</div>
                                <div className='creator-info-value'>{selectedCreator.mcn || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>Pricing</div>
                                <div className='creator-info-value'>{selectedCreator.pricing}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>Collab.</div>
                                <div className='creator-info-value'>{selectedCreator.collab || '--'}</div>
                            </div>
                        </div>
                        <div className='creator-info-3'>
                            <div className='creator-info-item'>
                                <div className='creator-info-label mail'>
                                    <Mail size={18} />
                                </div>
                                <div className='creator-info-value'>{selectedCreator.email || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label social'>
                                    <Instagram size={18} />
                                </div>
                                <div className='creator-info-value'>{selectedCreator.instagram || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label link'>
                                    <Link size={18} />
                                </div>
                                <div className='creator-info-value'>{selectedCreator.url || '--'}</div>
                            </div>
                        </div>
                    </div>
                    <div className='creator-data'>
                        <div className='levels'>
                            <div className='level-item'>
                                <div className='name'>E-commerce Level</div>
                                <div className='value'>{selectedCreator.ecommerceLevel || '--'}</div>
                            </div>
                            <div className='level-item'>
                                <div className='name'>Exposure Level</div>
                                <div className='value'>{selectedCreator.exposureLevel || '--'}</div>
                            </div>
                        </div>
                        <div className='data-cards'>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.followers || '--'}</div>
                                <div className='name'>Followers</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.gmv || '--'}</div>
                                <div className='name'>GMV</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.avgVideoViews || '--'}</div>
                                <div className='name'>Avg Video Views</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.itemsSold || '--'}</div>
                                <div className='name'>Items Sold</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.gpm || '--'}</div>
                                <div className='name'>GPM</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator.gpmPerCustomer || '--'}</div>
                                <div className='name'>GMV per customer</div>
                            </div>
                        </div>
                        <div className='data-charts'>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV per sales channel</div>
                                <Doughnut data={data} options={options} />
                            </div>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV by product category</div>
                                <Doughnut data={data} options={options} />
                            </div>
                        </div>
                    </div>
                </div>
            ) : (
                <div>No creator found</div>
            )}
        </div>
    );
}
